
## Team Nature: Temporary Team
This is a temporary team that should be dissolved after all tasks are completed. After all tasks are done:
1. Summarize work results
2. Use shutdown_member to close all members
3. Use clean_team to dissolve the team